@@ -6,26 +6,35 @@ use DynaLoader;
 use Socket ();
 use Config;
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 use constant {
 	INET_ATON     => 0,
 	INET_PTON     => 1,
 	GETHOSTBYNAME => 2,
-	GETADDRINFO   => 3
+	GETADDRINFO   => 3,
+	NEED_RTLD_GLOBAL => $Config{osname} =~ /linux/i && 
+	   !($Config{usethreads} || $Config{libs} =~ /-l?pthread\b/ || $Config{ldflags} =~ /-l?pthread\b/)
 };
 
 our @ISA = 'DynaLoader';
-sub dl_load_flags { 
-	if ($Config{osname} =~ /linux/i && 
-	   !($Config{usethreads} || $Config{libs} =~ /-l?pthread\b/ || $Config{ldflags} =~ /-l?pthread\b/))
-	{
+sub dl_load_flags {
+	if (NEED_RTLD_GLOBAL) {
 		return 0x01;
 	}
 	
 	return 0;
 }
 DynaLoader::bootstrap('Net::DNS::Native');
+if (NEED_RTLD_GLOBAL && &_is_non_safe_symbols_loaded) {
+	die sprintf(
+"***********************************************************************
+Some package defined non thread safe symbols which %s uses internally
+Please make sure you are not placed loading of modules like IO::Socket::IP
+before this one and not called functions like getaddrinfo(), gethostbyname(),
+inet_aton() before loading of %s
+************************************************************************", __PACKAGE__, __PACKAGE__);
+}
 
 sub _fd2socket($) {
 	open my $sock, '+<&=' . $_[0]
